/*
 *  Copyright (c) 2008 Luca Abeni
 *
 *  This is free software; see GPL.txt
 */
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>

#include "file_feed.h"

static char *path;

void set_path(const char *p)
{
    free(path);
    path = strdup(p);
}

char *full_file_name(const char *fname)
{
    char *p;

    p = malloc((path ? strlen(path) + 1 : 0) + strlen(fname) + 1);
    memset(p, 0, (path ? strlen(path) + 1 : 0) + strlen(fname) + 1);
    if (path) {
        strcpy(p, path);
	p[strlen(path)] = '/';
    }
    strcpy(p + (path ? strlen(path) + 1 : 0), fname);

    return p;
}

char *sdp_from_file(const char *fname)
{
    int fd, size;
    char *sdp;
    char *full_fname;

    full_fname = full_file_name(fname);
    fd = open(full_fname, O_RDONLY);
    free(full_fname);
    if (fd < 0) {
        return NULL;
    }

    size = lseek(fd, 0, SEEK_END);
    lseek(fd, 0, SEEK_SET);

    sdp = malloc(size + 1);
    if (sdp == NULL) {
        close(fd);

        return NULL;
    }

    read(fd, sdp, size);
    sdp[size] = 0;
    close(fd);

    if (memcmp(sdp, "v=0", 3)) {
        free(sdp);
	sdp = NULL;
    }
    return sdp;
}
