/*
 *  Copyright (c) 2008 Luca Abeni
 *
 *  This is free software; see GPL.txt
 */
struct insession_descr;

struct insession_methods {
    const char *(*get_url)(struct insession_descr *s);
    int (*get_sdp)(char *buff, int size, struct insession_descr *s);
    int (*set_sdp)(struct insession_descr *s, const char *sdp);

    struct insession *(*get)(const char *url);
    struct insession *(*allocate)(const char *url);
    void (*release)(struct insession_descr *s);
    void (*activate)(struct insession_descr *s, struct event_handler *h);

    struct media *(*media)(struct insession_descr *s, int i);

    void (*play)(struct insession_descr *s, struct rtp_session *r, int i);
    void (*stop)(struct insession_descr *s, struct rtp_session *r);
    struct insession_descr *ctx;
}; 

struct insession {
    struct insession_methods *ops;
    struct insession_descr *ctx;
};

extern struct insession_methods IS;
extern struct insession_methods IS_AVS;

static inline const char *insession_get_url(struct insession *s)
{
    return s->ops->get_url(s->ctx);
}

static inline int insession_get_sdp(char *buff, int size, struct insession *s)
{
    return s->ops->get_sdp(buff, size, s->ctx);
}

static inline int insession_set_sdp(struct insession *s, const char *sdp)
{
    return s->ops->set_sdp(s->ctx, sdp);
}

static inline struct insession *insession_get(const char *url)
{
#ifdef AVS
    if (memcmp(url + strlen(url) - 3, "sdp", 3)) {
        return IS_AVS.get(url);
    }
#endif

    return IS.get(url);
}

static inline struct insession *insession_allocate(const char *url)
{
    return IS.allocate(url);
}

static inline void insession_release(struct insession *s)
{
    s->ops->release(s->ctx);
}

static inline void insession_activate(struct insession *s, struct event_handler *h)
{
    s->ops->activate(s->ctx, h);
}

static inline struct media *insession_media(struct insession *s, int i)
{
    return s->ops->media(s->ctx, i);
}

static inline void insession_play(struct insession *s, struct rtp_session *r, int i)
{
    s->ops->play(s->ctx, r, i);
}

static inline void insession_stop(struct insession *s, struct rtp_session *r)
{
    s->ops->stop(s->ctx, r);
}
